summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2006-06-26 07:48:31 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:11:42 -0500
commitf5eac0c7faa920e877152a266d544288b4565989 (patch)
treeb3611e4518e23e5b3b6a985920fafb40b7ec3734 /png.h
parent6034592a27032ca1a518cb0ba502491a7590d046 (diff)
downloadlibpng-f5eac0c7faa920e877152a266d544288b4565989.tar.gz
Imported from libpng-1.2.11.tarv1.2.11
Diffstat (limited to 'png.h')
-rw-r--r--png.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/png.h b/png.h
index d1e6d3b17..63feee59d 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.11rc5 - June 23, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.11rc5 - June 23, 2006: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -153,7 +153,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.11rc5, June 23, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -265,13 +265,13 @@
* Y2K compliance in libpng:
* =========================
*
- * June 23, 2006
+ * June 26, 2006
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.11rc5 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.11 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -327,9 +327,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.11rc5"
+#define PNG_LIBPNG_VER_STRING "1.2.11"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.11rc5 - June 23, 2006 (header)\n"
+ " libpng version 1.2.11 - June 26, 2006 (header)\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -341,7 +341,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 5
+#define PNG_LIBPNG_VER_BUILD 0
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -358,7 +358,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_STABLE
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -1371,7 +1371,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_11rc5;
+typedef png_structp version_1_2_11;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.11rc5 - June 23, 2006
+ * libpng version 1.2.11 - June 26, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.11rc5 - June 23, 2006: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.11 - June 26, 2006: Glenn
* See also "Contributing Authors", below.
*
@@ -153,7 +153,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.11rc5, June 23, 2006, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.11, June 26, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5